Args

Struct Args 

pub struct Args {
Show 18 fields pub input_file: PathBuf, pub clk_freq: f64, pub clock_name: Option<String>, pub output_format: OutputFormat, pub limit_scope: Option<String>, pub limit_scope_power: Option<String>, pub netlist: Option<PathBuf>, pub top: Option<String>, pub top_scope: Option<String>, pub blackboxes_only: bool, pub remove_virtual_pins: bool, pub output: Option<PathBuf>, pub ignore_date: bool, pub ignore_version: bool, pub per_clock_cycle: bool, pub only_glitches: bool, pub export_empty: bool, pub input_ports_activity: bool,
}
trace2power - Extract acccumulated power activity data from VCD/FST

Fields

input_file: PathBuf

Trace file

clk_freq: f64

Clock frequency (in Hz)

clock_name: Option<String>

Clock signal name

output_format: OutputFormat

Format to extract data into

limit_scope: Option<String>

Scope in which signals should be looked for. By default it’s the global hierarchy scope.

limit_scope_power: Option<String>

Scope in which power will be calculated. By default it’s equal to limit_scope. Must be a subset of limit_scope.

netlist: Option<PathBuf>

Yosys JSON netlist of DUT. Can be used to identify ports of primitives when exporting data. Allows skipping unnecessary or unwanted signals

top: Option<String>

Name of the top module (DUT)

top_scope: Option<String>

Scope at which the DUT is located. The loaded netlist will be rooted at this point.

blackboxes_only: bool

Export only nets from blackboxes (undefined modules) in provided netlist. Those are assumed to be post-synthesis primitives

remove_virtual_pins: bool

Remove nets that are in blackboxes and have suspicious names: “VGND”, “VNB”, “VPB”, “VPWR”.

output: Option<PathBuf>

Write the output to a specified file instead of stdout. In case of per clock cycle output, it must be a directory.

ignore_date: bool

Ignore exporting current date.

ignore_version: bool

Ignore exporting current version.

per_clock_cycle: bool

Accumulate stats for each clock cycle separately. Output path is required to be a directory.

only_glitches: bool

Write stats only for glitches

export_empty: bool

Export without accumulation

input_ports_activity: bool

Set activity for input ports in TCL mode

Implementations

Source

impl Args

pub fn from_cli() -> Self